/* 
 * Plugin name: Export Workspace to CSV expanding parameters to columns
 * Plugin description: Exports workspace only selected layer to CSV. Splits parameters into columns
 * Plugin Author: Polskie Media
 * Plugin Created: 2024-05-24
 * 
 * Plugin Id: 3486cda3
 * Plugin Version: 1.0
 * 
 */
using AnnotationPro.Logic;
using AnnotationPro.Presentation;
using System.Linq;
using System.Text;
using System.IO;
using System.Windows.Forms;

namespace AnnotationPro.Plugin
{
    public class AnnotationPlugin : IAnnotationPlugin
    {
        private string LAYER_NAME = "SZDO_VOWELS - SRMA";

        public void Run(AnnotationEditor editor)
        {
            // BEGIN USER CODE

            if (editor.WorkspaceModeEnabled)
            {
                MessageBox.Show("Workspace Mode Not Allowed", "Workspace Mode Checking", MessageBoxButtons.OK, MessageBoxIcon.Information);
                return;
            }

            Annotation annotation = editor.Synchronizer.DataServer.Annotation;
            Audio audio = editor.Synchronizer.DataServer.Audio;
            WorkspaceControl workspace = editor.Workspace;

            StringBuilder csvBuilder = new StringBuilder();
            string header = string.Empty;
            foreach (var file in workspace.WorkspaceItems) {
                editor.OpenAnnotation(file.FilePath);

                LayerObject layer = annotation.Layers.FirstOrDefault(l => l.Name == LAYER_NAME);
                if (header == string.Empty)
                {
                    header = annotation.GetContentHeaderCSVString(CreateParamsCsvHeader(layer));
                    csvBuilder.Append(header);
                }
                string row = annotation.ExportLayerToCSVString(layer, true);
                csvBuilder.AppendLine(row);
            }
            
            string csv = csvBuilder.ToString();

            string csvPath = workspace.GetCsvFilePath();
            File.WriteAllText(csvPath, csv, Encoding.UTF8);

            // END USER CODE
        }

        private string CreateParamsCsvHeader(LayerObject layer)
        {
            var header = new StringBuilder();
            header.Append(ExtractComplexParamHeader(layer.Parameter1Name) + "\t");
            header.Append(ExtractComplexParamHeader(layer.Parameter2Name) + "\t");
            header.Append(ExtractComplexParamHeader(layer.Parameter3Name));
            return header.ToString();
        }

        private string ExtractComplexParamHeader(string parameterName)
        {
            var parts = parameterName.Split('+');
            return string.Join("\t", parts);
        }
    }
}